/*
 * Copyright 2009 OW2 Chameleon
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.chameleon.commons.dojo;

import org.osgi.service.http.HttpService;
import org.osgi.service.http.NamespaceException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * This component exposes the DOJO library as a web resource.
 * @author Clement Escoffier clement.escoffier@akquinet.de
 */
public class DOJOPublisher {

    /**
     * Alias where the library will be published.
     */
    public static final String ALIAS = "/dojotoolkit";

    /**
     * Internal published folder.
     */
    public static final String WEB = "web";

    /**
     * Logger.
     */
    private Logger logger = LoggerFactory
        .getLogger("org.ow2.chameleon.dojo-osgi");

    /**
     * Bind method called when the HTTP Service arrives.
     * @param http the http service
     */
    public synchronized void bindHTTP(HttpService http) {
        try {
            http.registerResources(ALIAS, WEB, null);
            logger.info("DOJO Toolkit published at : " + ALIAS);
        } catch (NamespaceException e) {
            logger.error("Cannot expose the DOJO toolkit", e);
        }
    }

    /**
     * Unbind method called when the HTTP Service leaves.
     * @param http the http service
     */
    public synchronized void unbindHTTP(HttpService http) {
        http.unregister(ALIAS);
        logger.info("DOJO Toolkit unpublished from : " + ALIAS);
    }

}
